betty.extension.nginx.docker module - Betty 0.4.0a1 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.extension.nginx.docker module

Integrate Betty with Docker.

class betty.extension.nginx.docker.Container

  Bases: `object`

  A Docker container with nginx, configured to serve a Betty site.

  Parameters:

    - www_directory_path (`pathlib.Path`)

    - docker_directory_path (`pathlib.Path`)

    - nginx_configuration_file_path (`pathlib.Path`)

  __init__(www_directory_path: pathlib.Path, docker_directory_path: pathlib.Path, nginx_configuration_file_path: pathlib.Path)
    Parameters:

      - www_directory_path (`pathlib.Path`)

      - docker_directory_path (`pathlib.Path`)

      - nginx_configuration_file_path (`pathlib.Path`)

  property ip: str

    The container’s public IP address.

  async start() → None

    Start the container.

    Return type:

      `None`

  async stop() → None

    Stop the container.

    Return type:

      `None`